Generate a list of rank-specific Bhat matrices (the coefficient of Ridge Redundancy Analysis for each parameter lambda and nrank). In our formula, Bhat is stored as LeftBhatlambda_k (p times r matrix) and RightBhatlambda_k (q times r). Here, n is the number of samples, p is the number of variables of X, q is the number of variables of Y, and r is the specified rank in the Ridge Redundancy Analysis.
Bhat_mat_rlist(Bhat_comp_1L, nrank)A list of matrices, each representing a rank-specific Bhat matrix.
A list containing components of Bhat for each lambda value.
A numeric vector indicating the rank(s) of Bhat.