Learn R Programming

rrda (version 0.2.3)

unbiased_scale: Scale a matrix using unbiased estimators for the mean and standard deviation.

Description

Scale a matrix using unbiased estimators for the mean and standard deviation.

Usage

unbiased_scale(x)

Value

A scaled numeric matrix.

Arguments

x

A numeric matrix to be scaled.